Always give simple circular rrects a shot at being directly blurred on the GPU

I believe we want to do this but split it out of https://codereview.chromium.org/2201133002/ (Implement GPU occluded blur mask filter) b.c. it has its own perf implications and changes several GMs on its own.

GOLD_TRYBOT_URL= https://gold.skia.org/search?issue=2232263002

Review-Url: https://codereview.chromium.org/2232263002
diff --git a/src/effects/SkBlurMaskFilter.cpp b/src/effects/SkBlurMaskFilter.cpp
index e0358bf..65ed7c5 100644
--- a/src/effects/SkBlurMaskFilter.cpp
+++ b/src/effects/SkBlurMaskFilter.cpp
@@ -1319,8 +1319,8 @@
         return false;
     }
 
-    // We always do circles on the GPU
-    if (!devRRect.isCircle()) {
+    // We always do circles and simple circular rrects on the GPU
+    if (!devRRect.isCircle() && !devRRect.isSimpleCircular()) {
         static const SkScalar kMIN_GPU_BLUR_SIZE  = SkIntToScalar(64);
         static const SkScalar kMIN_GPU_BLUR_SIGMA = SkIntToScalar(32);